function addpaths()

%% Local paths
root_paths = { ...
    './dist-measures', ...
    './netflow', ...
    './shpaths', ...
    './utils' ...
};

fprintf('Adding paths to MATLABPATH...\n');
tic;
for path = root_paths
	try
		addpathx(path);
	catch
		fprintf(2, '\t- Unable to add path ''%s''\n', path{:});
	end
end
fprintf('DONE in %fsec.\n', toc);

%% GraphViz
if(dir_exists('/opt/local/bin'))
    fprintf('Adding "/opt/local/bin" to PATH to reach graphViz binaries... ');
	try
		evalc('addtosystempath(''/opt/local/bin'')');
	catch
		fprintf(2, 'Failed to add paths for GraphViz. ');
	end
    fprintf('DONE.\n');
end

%% CPLEX
try
	fprintf('Looking for CPLEX... ');
	
	cplex_path = [ ];
	cplex_found = false;
	
	% searching for CPLEX in common locations (e.g., ~/opt/, /opt/)
	[~, homedir] = unix('echo $HOME');
	homedir = strtrimx(homedir);
	optdirs = { fullfile(homedir, '/opt/'), '/opt/' };
	for ioptdir = 1 : length(optdirs)
		optdir = optdirs{ioptdir};

		if(dir_exists(optdir))
			entries = dir(optdir);
			dir_entry_indic = [ entries(:).isdir ];
			entries = { entries(dir_entry_indic).name }';
			for i = 1 : length(entries)
				entry = entries{i};
				entry_dir = fullfile(optdir, entry);
				if(dir_exists(entry_dir) && strcmp('cplex', substrx(entry, 1, length('cplex'))))
					cplex_path = fullfile(entry_dir, 'cplex', 'matlab');
					cplex_found = true;
					break;
				end
			end
		end

		if(cplex_found)
			break;
		end
	end

	% searching for CPLEX using locate utility
	if(~cplex_found)
		[~, cout] = unix('locate cplexlp.m');
		if(~isempty(cout))
			cand_paths = strsplit(strtrim(cout));
			for i = length(cand_paths) : -1 : 1
				cand_path = cand_paths{i};
				if(strfind(cand_path, '/cplex/matlab/'))
					cplex_path = fileparts(cand_path);
					cplex_found = true;
					break;
				end
			end
		end
	end
	
	if(cplex_found)
		fprintf('found "%s" ', cplex_path);
		addpathx(cplex_path, true);
	else
		fprintf(2, 'CPLEX NOT FOUND! ');
	end
	fprintf('DONE.\n');
catch

end

end
