fprintf(2, '-- SND Computation Example --\n');
t = tic;

%% Settings

% Weight for each (initially present) edge in the adjacency matrix
social_proximity = 1;

% Each single edge e gets a reverse edge weighted with edge_doubling_factor * weight(e)
edge_doubling_factor = 1000; 

% Opinion propagation cost model (simple model)
% (in this example, user in state "+" charges 1000 for adopting or spreading opinion "-")
cost_model = snd_simple_cost_model(struct('costs', [
% (opinion being propagated)
%         -     +
          5, 1000;  %  -
         40,   40;  %  N (acting user's opinion)
       1000,    5   %  +
]));

%% Defining opinion distributions

P = sparse([ +1 -1  0 +1 -1  0 -1  0 +1  0 ]);
Q = sparse([ +1 -1  0 +1 -1 -1  0 +1 -1 +1 ]);
nnodes = length(P);

%% Defining network's adjacency matrix

adj = sparse([
    0  0  1  0  0  0  0  0  0  0;
    0  0  1  0  0  0  0  0  0  0;
    1  1  0  1  0  0  0  0  0  0;
    0  0  1  0  1  0  1  0  0  0;
    0  0  0  1  0  1  0  0  0  0;
    0  0  0  0  1  0  0  0  0  0;
    0  0  0  1  0  0  0  1  1  0;
    0  0  0  0  0  0  1  0  1  1;
    0  0  0  0  0  0  1  1  0  1;
    0  0  0  0  0  0  0  1  1  0;
]);
adj(adj == 1) = social_proximity;
adj = double_edges(adj, edge_doubling_factor);
if(conncomp(adj) > 1)
    error('If there are many weakly connected components, apply SND component-wise.');
end

%% Computation of SND with a minimum required number of options

fprintf('* computing SND (minimal # of parameters)... ');
dist1 = snd(P, Q, adj, cost_model); % or 0.5 * (snd(P, Q, adj, cost_model) + snd(Q, P, adj, cost_model))
fprintf('SND = %f\n', dist1);

%% Computation of SND with more options

fprintf('* computing SND (extended version)... ');

options = struct( ...
    'mcf_solver', @gt_transport, ...
    'sp_solver', @radix_dijkstra ...
);

gamma = social_proximity; % weight of the edges to the auxilary "bank-bins" for EMD*

dist2 = snd(P, Q, adj, cost_model, gamma, options);

fprintf('SND = %f\n', dist2);

fprintf(2, '-- DONE in %fsec ------------\n\n', toc(t));