fprintf(2, '-- SND Computation Example (disconnected network) --\n');
t = tic;

%% Settings

% Network properties
nnodes = 10000; % approximate number of nodes (also, upper bound)
ncc = 10; % number of connected components
deg_exp = -1.11; % exponent for degree sequence generation
max_degree = 1000; % approximate maximum node degree

% Weight for each (initially present) edge in the adjacency matrix
social_proximity = 1;

% Each single edge e gets a reverse edge weighted with edge_doubling_factor * weight(e)
edge_doubling_factor = 1000; 

% SND's model for opinion propagation costs
cost_model = snd_simple_cost_model(struct('costs', [
% (opinion being propagated)
%         -     +
          5, 1000;  %  -
         40,   40;  %  N (acting user's opinion)
       1000,    5   %  +
]));

%% Defining network's adjacency matrix

fprintf('* generating network''s structure... '); tic;
adj = sparse([ ]);
for icc = 1 : ncc
    nnodes_cc = round(nnodes / ncc);
    node_degrees = max(1, round(max_degree * (1 : nnodes_cc) .^ deg_exp));
    adj_cc = sparse(nnodes_cc, nnodes_cc);
    for icol = 1 : nnodes_cc
        deg = node_degrees(icol);
        deg = min(nnodes_cc, round(abs(normrnd(deg, deg / 10, 1, 1))));
        pr_edge = deg / nnodes_cc;
        adj_cc(:, icol) = randsample([1, 0], nnodes_cc, true, [pr_edge, 1 - pr_edge]);
    end
    adj_cc = double(adj_cc + adj_cc' > 0);
    adj_cc = get_largest_conncomp(adj_cc, true, true);
    nnodes_cc = size(adj_cc, 1);
    ccidx = size(adj, 1) + 1 : size(adj, 1) + nnodes_cc;
    adj(ccidx, ccidx) = adj_cc;
end
nnodes = size(adj, 1);
ridx = randperm(nnodes);
adj = adj(ridx, ridx);
fprintf('DONE in %fsec.\n', toc);

%% Defining opinion distributions

fprintf('* generating network states... '); tic;
gensig = @(n) sparse(randsample([-1, 0, +1], n, true, [0.1, 0.8, 0.1]))';
P = gensig(nnodes);
Q = gensig(nnodes);
fprintf(' (# diff = %d) ', nnz(P ~= Q));
fprintf('DONE in %fsec.\n', toc);

%% Computation of SND

adj(adj == 1) = social_proximity;
% adj = double_edges(adj, edge_doubling_factor); % -- done for non-symmetric connected networks

gamma = social_proximity;

[nconcomp, concomp_idx] = conncomp(adj, true, true);

fprintf('* computing SND for each connected component (non-zero values reported)...\n'); tic;
dist = 0;
for icc = 1 : nconcomp
    cc_indic = concomp_idx == icc;
    adj_cc = adj(cc_indic, cc_indic);
    P_cc = P(cc_indic);
    Q_cc = Q(cc_indic);
    dist_cc = snd(P_cc, Q_cc, adj_cc, cost_model, gamma); % or 0.5 * (snd(P_cc, Q_cc, adj_cc, cost_model, gamma) + snd(Q_cc, P_cc, adj_cc, cost_model, gamma))
    dist = dist + dist_cc;
    if(dist_cc > 0)
        fprintf('\t- [cc%d] SND = %f\n', icc, dist_cc);
    end
end
fprintf('\t- SND = %f\n', dist);
fprintf('* DONE in %fsec.\n', toc);

fprintf(2, '-- ALL DONE in %fsec ------------\n\n', toc(t));