function [ available ] = cplex_available(use_file_flags)
%CPLEX_AVAILABLE Checks whether CPLEX is available

if(nargin < 1)
    use_file_flags = false;
end

if(use_file_flags)
    cplex_flag_fpaths = { ...
        [ pwd, '/cplex-not-available.flag' ], ...
        [ pwd, '/cplex-available.flag' ] ...
    };
    if(file_exist(cplex_flag_fpaths{1}))
        available = false;
        return;
    elseif(file_exist(cplex_flag_fpaths{2}))
        available = true;
        return;
    end
end

available = false;
code = exist('cplexlp', 'file');
if(code == 6 || code == 3)
    eps = 10e-5;
    fun_args = '([-2, 5], [1, 1], [200], [], [], [100, 80], [200, 170])';
    [~, cp_argmin, cp_min] = evalc(['cplexlp', fun_args]);
    [~, lp_argmin, lp_min] = evalc(['linprog', fun_args]);
    if(abs(cp_min - lp_min) <= eps && norm(cp_argmin - lp_argmin, 1) <= eps)
        available = true;
    end
end

if(use_file_flags)
    if(available)
        fpath = cplex_flag_fpaths{2};
    else
        fpath = cplex_flag_fpaths{1};
    end
    unix(sprintf('touch "%s"', fpath));
end

end

