function [ agreed ] = prompt_agree_to_license(product_title, lic_fpath)
%PROMPT_AGREE_TO_LICENSE

if(nargin < 2)
    error('Provide the name of the product and the path to the file containing license text.');
end

lic_fpath_original = lic_fpath;
lic_fpath = which(lic_fpath);
if(isempty(lic_fpath))
    error('Unable to find license file %s.', lic_fpath_original);
end
[ dirpath, fname, fext ] = fileparts(lic_fpath);
lic_agreed_fpath = fullfile(dirpath, [fname, '-agreed', fext]);

if(exist(lic_agreed_fpath, 'file'))
    agreed = true;
    return;
end

h = fopen(lic_fpath, 'r');
if(h < 0)
    warning('Unable to open license file %s.', licfpath);
    agreed = false;
    return;
end

[text, textlen] = fread(h);
if(textlen <= 0)
    warning('License file %s is empty.', licfpath);
    agreed = false;
    return;
end

fclose(h);

fprintf('\n-- %s License ----------------------------------------\n\n', product_title);
fprintf('%s', text);
fprintf('\n------------------------------------------------------\n\n');

response = '';
repetition = false;
while(length(intersect({'y', 'yes', 'n', 'no'}, { response })) <= 0)
    msg = sprintf('Have you read and accepted the license for %s? [yes/no] ', product_title);
    if(repetition)
        msg = [msg, 'Type y(es) or n(o). '];
    end
    response = lower(input(msg, 's'));
    repetition = true;
end

if(response(1) == 'n')
    agreed = false;
    return;
end

h = fopen(lic_agreed_fpath, 'w');
fwrite(h, 'Copyright/license has been read and agreed upon.');
fclose(h);

agreed = true;

end

