function [ newvec ] = contract_vec(vec, chunk_size, aggr_fun)
%CONTRACT_VEC Composes a new vector our of chunks of a vector; each chunk is
% processed with aggre_fun function, which is sum by default

if(~isvector(vec) || ~isscalar(chunk_size))
    error('Invalid input.');
end
if(nargin < 3)
    aggr_fun = @sum;
end

nchunks = ceil(length(vec) / chunk_size);
newvec = zeros(nchunks, 1);
if(size(vec, 1) < size(vec, 2))
    newvec = newvec';
end

for i = 1 : nchunks
    istart = (i - 1) * chunk_size + 1;
    iend = min(length(vec), istart + chunk_size - 1);
    newvec(i) = aggr_fun(vec(istart : iend));
end

end

